@@ -33,14 +33,19 @@ from fui.locker import LockerMessageFactory as _
 
 
 RANGE_DESCRIPTION = u"""One locker-range per line. Each line must contain a
-label (a description of where the lockers are located), followed by two
-numbers separated by '-'. The numbers define a valid locker-number range.
-Example line: 1000-2999. This line will make any number between 1000 and 2999,
-including the two numbers, a valid locker number. You can define as many ranges
-as you like, each on a separate line."""
+label (a description of where the lockers are located), followed by 
+number-ranges ('-' separated by numbers). The numbers define a valid
+locker-number range. Example line: 'Bachelor lesesal:110-120,122-150'.
+This line will make any number between 110 and 150, including the two numbers
+and excluding 121, a valid locker number. You can define as many ranges as you
+like, each on a separate line."""
 
 LOCKERLIST_PATT = re.compile("^.+?:(\d+-\d+)(,\d+-\d+)*$")
 
+LOCKER_EXAMPLE = \
+u"""Bachelor lesesal:110-120,122-150
+Bachelorlesesal 1.etg:4001-4010,4013-4020,4100-4130"""
+
 
 EMAIL_TPL = \
 u"""Someone has registered locker '%(lockerid)s' with your username
@@ -52,9 +57,6 @@ Fagutvalget ved Institutt for informatikk (FUI)
 http://fui.ifi.uio.no"""
 
 
-LOCKER_EXAMPLE = \
-u"""Example room one:100-130,201-300
-Bachelorlesesal 1.etg:4001-4010,4013-4020,4100,4130"""
 
 
 EMAIL_DESCRIPTION = \
